@@ -73,14 +73,14 @@
  *
  * Configures the inclusion of the debugging subsystem
  */
-/* #undef GST_DISABLE_GST_DEBUG */
+#undef GST_DISABLE_GST_DEBUG
 
 /**
  * GST_DISABLE_PARSE:
  *
  * Configures the inclusion of the gst-launch parser
  */
-/* #undef GST_DISABLE_PARSE */
+#undef GST_DISABLE_PARSE
 
 /**
  * GST_DISABLE_REGISTRY:
@@ -89,11 +89,33 @@
  * If one disables this, required plugins need to be loaded and registered
  * manually
  */
-/* #undef GST_DISABLE_REGISTRY */
+#undef GST_DISABLE_REGISTRY
+
+/**
+ * GST_DISABLE_CAST_CHECKS:
+ *
+ * Disable run-time GObject cast checks
+ */
+#define GST_DISABLE_CAST_CHECKS 0
+
+/**
+ * GST_DISABLE_GLIB_ASSERTS:
+ *
+ * Disable GLib assertion
+ */
+#define GST_DISABLE_GLIB_ASSERTS 0
+
+/**
+ * GST_DISABLE_GLIB_CHECKS:
+ *
+ * Disable GLib checks such as API guards
+ */
+#define GST_DISABLE_GLIB_CHECKS 0
+
 
 /* FIXME: test and document these! */
 /* Configures the use of external plugins */
-/* #undef GST_DISABLE_PLUGIN */
+#undef GST_DISABLE_PLUGIN
 
 /* Whether or not the CPU supports unaligned access
  * The macros used are defined consistently by GCC, Clang, MSVC, Sun, and ICC
@@ -104,7 +126,7 @@
  * http://docs.oracle.com/cd/E19205-01/820-4155/c++_faq.html#Vers6
  * https://software.intel.com/en-us/node/583402
  */
-#if defined(__alpha__) || defined(__arc__) || defined(__arm__) || defined(__aarch64__) || defined(__bfin) || defined(__hppa__) || defined(__nios2__) || defined(__MICROBLAZE__) || defined(__mips__) || defined(__or1k__) || defined(__sh__) || defined(__SH4__) || defined(__sparc__) || defined(__sparc) || defined(__ia64__) || defined(_M_ALPHA) || defined(_M_ARM) || defined(_M_IA64) || defined(__xtensa__) || defined(__e2k__)
+#if defined(__alpha__) || defined(__arc__) || defined(__arm__) || defined(__aarch64__) || defined(__bfin) || defined(__hppa__) || defined(__nios2__) || defined(__MICROBLAZE__) || defined(__mips__) || defined(__or1k__) || defined(__sh__) || defined(__SH4__) || defined(__sparc__) || defined(__sparc) || defined(__ia64__) || defined(_M_ALPHA) || defined(_M_ARM) || defined(_M_IA64) || defined(__xtensa__) || defined(__e2k__) || defined(__riscv)
 #  define GST_HAVE_UNALIGNED_ACCESS 0
 #elif defined(__i386__) || defined(__i386) || defined(__amd64__) || defined(__amd64) || defined(__x86_64__) || defined(__ppc__) || defined(__ppc64__) || defined(__powerpc__) || defined(__powerpc64__) || defined(__m68k__) || defined(_M_IX86) || defined(_M_AMD64) || defined(_M_X64) || defined(__s390__) || defined(__s390x__) || defined(__zarch__)
 #  define GST_HAVE_UNALIGNED_ACCESS 1
@@ -155,8 +177,18 @@
 # endif
 #endif
 
+#if defined(_MSC_VER) && !defined(GST_STATIC_COMPILATION)
+# define GST_API_IMPORT __declspec(dllimport) extern
+#else
+# define GST_API_IMPORT extern
+#endif
+
 #ifndef GST_API
-#define GST_API GST_EXPORT
+# ifdef BUILDING_GST
+#  define GST_API GST_API_EXPORT        /* from config.h */
+# else
+#  define GST_API GST_API_IMPORT
+# endif
 #endif
 
 /* These macros are used to mark deprecated functions in GStreamer headers,
